@@ -7,7 +7,7 @@ use Log::Any '$log';
 use LWP::Simple;
 use Parse::Number::ID qw(parse_number_id);
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_currencies convert_currency);
@@ -15,18 +15,20 @@ our @EXPORT_OK = qw(get_currencies convert_currency);
 our %SPEC;
 
 $SPEC{get_currencies} = {
-    summary => 'Extract data from KlikBCA page',
+    summary => 'Extract data from KlikBCA/BCA page',
     v => 1.1,
 };
 sub get_currencies {
     my %args = @_;
 
+    #return [543, "Test parse failure response"];
+
     my $page;
     if ($args{_page_content}) {
         $page = $args{_page_content};
     } else {
         $page = get "http://www.bca.co.id/id/biaya-limit/kurs_counter_bca/kurs_counter_bca_landing.jsp"
-            or return [500, "Can't retrieve KlikBCA page"];
+            or return [500, "Can't retrieve BCA page"];
     }
 
     $page =~ s!(<table .+? Mata\sUang .+?</table>)!!xs
@@ -99,21 +101,20 @@ sub get_currencies {
     [200, "OK", {update_date=>undef, currencies=>\%items}];
 }
 
+# used for testing only
 our $_get_res;
 
 sub convert_currency {
     my ($n, $from, $to) = @_;
 
-    # XXX set expiry
-    if (!$_get_res) {
+    unless ($_get_res) {
         $_get_res = get_currencies();
-        warn "Can't get currencies: $_get_res->[0] - $_get_res->[1]\n";
-        return undef;
-    }
-    if ($_get_res->[0] != 200) {
-        warn "get currencies failed: $_get_res->[0] - $_get_res->[1]\n";
-        return undef;
+        unless ($_get_res->[0] == 200) {
+            warn "Can't get currencies: $_get_res->[0] - $_get_res->[1]\n";
+            return undef;
+        }
     }
+
     if (uc($to) ne 'IDR') {
         die "Currently only conversion to IDR is supported".
             " (you asked for conversion to '$to')\n";
@@ -124,7 +125,7 @@ sub convert_currency {
 }
 
 1;
-# ABSTRACT: Convert currencies using KlikBCA
+# ABSTRACT: Convert currencies using data from KlikBCA/BCA
 
 __END__
 
@@ -134,11 +135,11 @@ __END__
 
 =head1 NAME
 
-Finance::Currency::Convert::KlikBCA - Convert currencies using KlikBCA
+Finance::Currency::Convert::KlikBCA - Convert currencies using data from KlikBCA/BCA
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -156,7 +157,8 @@ Currently can only handle conversion *to* IDR. Dies if given other currency.
 
 Will warn if failed getting currencies from the webpage.
 
-Currency rate is cached.
+Currency rate is not cached (retrieved from the website every time). Employ your
+own caching.
 
 Currently uses the Bank Notes rate.
 
@@ -168,7 +170,7 @@ if you need the more complete result.
 
 =head2 get_currencies() -> [status, msg, result, meta]
 
-Extract data from KlikBCA page.
+Extract data from KlikBCA/BCA page.
 
 No arguments.
 
